playlist

package
v0.0.0-...-f915236 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 12, 2011 License: GPL-3.0 Imports: 2 Imported by: 0

Documentation

Overview

Playlist package implements playlist, -- ordered list of tracks to be played, abstraction.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Playlist

type Playlist struct {
	// contains filtered or unexported fields
}

Playlist

func New

func New(name string) *Playlist

New returns an initialized playlist.

func (*Playlist) Append

func (pl *Playlist) Append(tracks ...*vfs.Track)

Append appends new tracks at the end of the playlist.

func (*Playlist) Clear

func (pl *Playlist) Clear()

Clear removes all items from the playlist.

func (*Playlist) IsSystem

func (pl *Playlist) IsSystem() bool

IsSystem returns true if playlist is system and can't be created/deleted by user. System playlist is a playlist that has a name strats and ends with asterisk.

func (*Playlist) Len

func (pl *Playlist) Len() int

Len returns the total number of tracks present in playlist.

func (*Playlist) Name

func (pl *Playlist) Name() string

Name returns name of the playlist.

func (*Playlist) Track

func (pl *Playlist) Track(n int) *vfs.Track

Track returns track by its position.

func (*Playlist) Tracks

func (pl *Playlist) Tracks() []*vfs.Track

Tracks returns list of tracks presented in the playlist.

Jump to